@@ -1,14 +1,16 @@
 #!/usr/bin/env python2
 # coding=utf-8
 
-# Last modified: <2012-08-05 19:37:10 Sunday by richard>
+# Last modified: <2012-12-11 15:32:49 Tuesday by richard>
 
 # @version 0.1
 # @author : Richard Wong
 # Email: chao787@gmail.com
+
+
 def is_type(re_pattern, s):
     m = re_pattern.match(s)
-    if m == None or m.span() != (0, len(s)):
+    if m is None or m.span() != (0, len(s)):
         return False
     return True
 
